package com.zfire.jiasm.syncdata.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.data.Token;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.service.MasterDownloadService;
import com.zfire.jiasm.syncdata.utils.DataUtil;
import com.zfire.jiasm.syncdata.utils.HttpUtil;
import com.zfire.jiasm.syncdata.utils.JSONResult;
import com.zfire.jiasm.syncdata.utils.MyBeanUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

import static jdk.nashorn.internal.objects.NativeString.trim;

@Slf4j
@Service
public class MasterDownloadServiceImpl implements MasterDownloadService {
	@Value("${masterbaseurl}")
	private String masterbaseurl = "";

	@Resource
	ItfTblWxCpgzDownloadService itfTblWxCpgzDownloadService;
	@Resource
	ItfTblWxGzdmWxxmjcDownloadService itfTblWxGzdmWxxmjcDownloadService;
	@Resource
	ItfTblWxWxxmjcDownloadService itfTblWxWxxmjcDownloadService;
	@Resource
	RepairBugService repairBugService;
	@Resource
	RepairProjectService repairProjectService;
	@Resource
	ItfJhAzdCauseSortNewDownloadService itfJhAzdCauseSortNewDownloadService;
	@Resource
	ItfTblWxCpgzXjdDownloadService itfTblWxCpgzXjdDownloadService;
	@Resource
	ItfJhAzdCauseAtterDownloadService itfJhAzdCauseAtterDownloadService;
	@Resource
	ItfTblWxWxxmXjdDownloadService itfTblWxWxxmXjdDownloadService;
	@Resource
	RepairProjectTypeService repairProjectTypeService;
	@Resource
	ItfGreeToFaDownloadTaskService itfGreeToFaDownloadTaskService;

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void batchDownload(Token token, String[] arySrcTabName,String[] aryDestTabName,
							  String belongCompany, int reqId, Brand brandRec) throws Exception {
		// 移除故障代码 + 维修项目
		processDelete(brandRec);

		String synTaskNo = UUID.randomUUID().toString();
		for (int i = 0; i < arySrcTabName.length; i++) {
			String srcTabName = arySrcTabName[i].trim();
			String serviceName = DataUtil.fromDbName2ServiceName(srcTabName);
			String url = masterbaseurl + serviceName + "/querylist";
			Map<String, String> paramMap = new HashMap<String, String>();
			if(belongCompany!=null && belongCompany.trim().length()>0) {
				paramMap.put("belongCompany", belongCompany);
			}
			String paramJson= JSON.toJSONString(paramMap);
			JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
			JSONArray jsonArray = (JSONArray) jsonResult.getData();
			if (jsonArray != null) {
				log.info("["+url+"]下载了["+jsonArray.size()+"]条数据");
				masterProcess(aryDestTabName, brandRec, synTaskNo, i, jsonArray, reqId);
				log.info("["+url+"]插入了["+jsonArray.size()+"]条数据");
			}else {
				log.info("["+url+"]无数据");
			}
		}

		ItfGreeToFaDownloadTask up = new ItfGreeToFaDownloadTask();
		up.setId(reqId);
		up.setNeedDownload(0);
		up.setLastDownloadTime(new Date());
		itfGreeToFaDownloadTaskService.updateById(up);
	}

	private void processDelete(Brand brandRec) {
		QueryWrapper del = new QueryWrapper<RepairBug>()
				.eq("brand_id", brandRec.getBrandId());
		repairBugService.remove(del);

		QueryWrapper delt = new QueryWrapper<RepairProject>()
				.eq("brand_id", brandRec.getBrandId());
		repairProjectService.remove(delt);
	}


	public void masterProcess(String[] aryDestTabName, Brand brandRec, String synTaskNo, int i, JSONArray jsonArray,int reqId) {

		if (aryDestTabName[i].equals("itf_tbl_wx_cpgz_download")){
			// 维修－产品故障基表下载记录 + 故障现象(repair_bug)                                               OK
			// addItfTblWxCpgzDownload(synTaskNo, jsonArray, brandRec);
		} else if (aryDestTabName[i].equals("itf_tbl_wx_gzdm_wxxmjc_download")){
			// 故障代码与维修项目基础表下载记录 OK 有故障代码 维修项目(商用空调｜家用空调)                          待测试
			// addItfTblWxGzdmWxxmjcDownload(synTaskNo, jsonArray, brandRec);
		} else if (aryDestTabName[i].equals("itf_tbl_wx_wxxmjc_download")){
			// 维修项目基础表下载记录 + (repair_project) + 维修项目分组取 无故障代码  维修项目(商用空调) OK
			// masterDownloadService.addItfTblWxWxxmjcDownload(synTaskNo, jsonArray,brandRec);
		} else if (aryDestTabName[i].equals("itf_jh_azd_cause_sort_new_download")){
			// 晶弘冰箱故障代码基础表下载记录                                                                  OK
			// addItfJhAzdCauseSortNewDownload(synTaskNo, jsonArray, brandRec);
		} else if (aryDestTabName[i].equals("itf_jh_azd_cause_atter_download")){
			// 晶弘冰箱维修项目基础表下载记录 + (repair_project) OK 有故障代码 维修项目(晶弘冰箱)                  OK
			addItfJhAzdCauseAtterDownload(synTaskNo, jsonArray,brandRec);
		} else if (aryDestTabName[i].equals("itf_tbl_wx_cpgz_xjd_download")){
			// 小家电故障现象基础表下载记录 select * from itf_tbl_wx_cpgz_xjd_download;
			// addItfTblWxCpgzXjdDownload(synTaskNo, jsonArray,brandRec);
		} else if (aryDestTabName[i].equals("itf_tbl_wx_wxxm_xjd_download")){
			// 小家电维修项目基础表下载记录 + (repair_project)  这里给了小类信息  OK  维修项目(生活电器)
			// addItfTblWxWxxmXjdDownload(synTaskNo, jsonArray,brandRec);
		}
	}

	public void addItfTblWxCpgzDownloadOld(String synTaskNo, JSONArray jsonArray, Brand brandRec){
		List<ItfTblWxCpgzDownload> addRec = new ArrayList<>();
		List<ItfTblWxCpgzDownload> upRec = new ArrayList<>();
		List<RepairBug> addRepairBug = new ArrayList<>();
		List<RepairBug> upRepairBug = new ArrayList<>();

		getItfTblWxCpgzDownload(synTaskNo, jsonArray, addRec, upRec);

		// 新增
		if (addRec.size()>0){
			getAddRepairBug(brandRec, addRec, addRepairBug);
		}
		if (addRec.size()>0){
			getAddRepairBugTY(brandRec, addRec, addRepairBug);
		}

		// 修改
		if (upRec.size()>0){
			getUpRepairBug(upRec, upRepairBug);
		}
		if (upRec.size()>0){
			getUpRepairBugSY(upRec, upRepairBug);
		}

		// 新增的插入到表 维修－产品故障基表下载记录
		if (addRec.size()>0){
			itfTblWxCpgzDownloadService.saveBatch(addRec);
			log.info("产品故障基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
		if (addRepairBug.size()>0){
			repairBugService.saveBatch(addRepairBug);
			log.info("产品故障表信息同步新增插入了{}条数据", addRepairBug.size());
			addRepairBug.clear();
		}

		if (upRec.size()>0){
			itfTblWxCpgzDownloadService.updateBatchById(upRec);
			log.info("产品故障基表信息同步修改了{}条数据", upRec.size());
			upRec.clear();
		}

		if (upRepairBug.size()>0){
			repairBugService.updateBatchById(upRepairBug);
			log.info("产品故障表信息同步修改了{}条数据", upRepairBug.size());
			upRepairBug.clear();
		}
		// 这里增加一条 晶弘冰箱 维修项目数据
		// addRepairProject(brandRec);
	}

	public void addItfTblWxCpgzDownload(String synTaskNo, JSONArray jsonArray, Brand brandRec){
		List<ItfTblWxCpgzDownload> addRec = new ArrayList<>();
		List<RepairBug> addRepairBug = new ArrayList<>();
		getItfTblWxCpgzDownloadT(synTaskNo, jsonArray, addRec);

		// 新增
		if (addRec.size()>0){
			getAddRepairBugT(brandRec, addRec, addRepairBug);
			getAddRepairBugSY(brandRec, addRec, addRepairBug);

			// 新增的插入到表 维修－产品故障基表下载记录
			itfTblWxCpgzDownloadService.saveBatch(addRec);
			log.info("产品故障基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}

		// 新增的插入到表 维修－产品故障基表下载记录
		if (addRec.size()>0){
			itfTblWxCpgzDownloadService.saveBatch(addRec);
			log.info("产品故障基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}

		// 添加一条 家用空调 维修项目分类信息
		addRepairProjectType(1, "家用空调");

		// 这里增加一条 晶弘冰箱 维修项目数据
		// addRepairProject(brandRec);
	}

	private void addRepairProjectType(int i, String name) {
		// 移除原有的
		QueryWrapper del = new QueryWrapper<RepairProjectType>()
				.eq("type", i);
		repairProjectTypeService.remove(del);

		RepairProjectType n = new RepairProjectType();
		n.setParentId(0);
		n.setName(name);
		n.setStatus(1);
		n.setType(i);
		// n.setCreateTime(new Date());
		// n.setUpdateTime(new Date());
		n.setCreateBy("system");
		n.setUpdateBy("system");
		repairProjectTypeService.save(n);
	}


	private void addRepairProject(Brand brandRec) {
		List<RepairProject> rps = repairProjectService.lambdaQuery()
				.eq(RepairProject::getRepairProjectType,"晶弘冰箱").list();
		if (CollectionUtils.isEmpty(rps)){
			RepairProject add = new RepairProject();
			add.setRepairProjectId(UUID.randomUUID().toString());
			add.setBrandId(brandRec.getBrandId());
			add.setBrandName(brandRec.getBrand());
			add.setRepairProjectCode(IdWorker.getIdStr());
			add.setRemark("晶弘冰箱");
			add.setRepairProjectType("晶弘冰箱");
			add.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			add.setCreateBy("system");
			add.setCreateTime(new Date());
			repairProjectService.save(add);
		}
	}

	public void addItfTblWxGzdmWxxmjcDownload(String synTaskNo, JSONArray jsonArray, Brand brandRec){
		List<ItfTblWxGzdmWxxmjcDownload> addRec = new ArrayList<>();
		List<RepairProject> addres = new ArrayList<>();

		getItfTblWxGzdmWxxmjcDownloadT(synTaskNo, jsonArray, addRec);

		if (addRec.size()>0){
			// 新增到维修项目表
			getAddres(brandRec, addRec, addres);
		}


		// 新增的插入到表 维修－产品故障基表下载记录
		if (addRec.size()>0){
			itfTblWxGzdmWxxmjcDownloadService.saveBatch(addRec);
			log.info("故障代码与维修项目基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
		if (addres.size()>0){
			repairProjectService.saveBatch(addres);
			log.info("维修项目表信息同步新增了{}条数据", addres.size());
			addres.clear();
		}

		// 移除原有的
		addRepairProjectType(4, "晶弘冰箱");

	}

	private void getUpres(List<ItfTblWxGzdmWxxmjcDownload> upRec, List<RepairProject> upres) {
		List<String> rpid = new ArrayList<>();
		upRec.forEach(i->{
			rpid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairProject> rbs = repairProjectService.lambdaQuery()
				.in(RepairProject::getRepairProjectId,rpid)
				.in(RepairProject::getRepairProjectType,"商用空调","家用空调").list();
		Map<String,List<RepairProject>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairProject::getRepairProjectId));

		for (ItfTblWxGzdmWxxmjcDownload item: upRec){
			if (!rbsMap.containsKey(item.getId())){
				continue;
			}
			RepairProject u = new RepairProject();
			u = rbsMap.get(item.getId()).get(0);

			u.setBugObjCode(item.getXxyyh());
			u.setRepairProjectCode(item.getWxxmh());
			u.setRemark(item.getWxxm());
			u.setRepairProjectType("1");
			if (item.getCpsx().equals(2)){
				u.setRepairProjectType("2");
			}

			u.setUpdateBy("system");
			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upres.add(u);
		}
	}

	private void getAddres(Brand brandRec, List<ItfTblWxGzdmWxxmjcDownload> addRec, List<RepairProject> addres) {
		for (ItfTblWxGzdmWxxmjcDownload item: addRec){
			String repairProjectType="1";
			if (item.getCpsx().equals(2)){
				repairProjectType = "2";
			}
			// 提取原有的
			RepairProject rp = repairProjectService.lambdaQuery()
					.eq(RepairProject::getRepairProjectType,repairProjectType)
					.eq(RepairProject::getBugObjCode,item.getXxyyh())
					.eq(RepairProject::getRepairProjectCode,item.getWxxmh()).one();
			if (rp !=null){
				continue;
			}
			RepairProject v = new RepairProject();
			v.setRepairProjectId(item.getId());
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setBugObjCode(item.getXxyyh());
			v.setRepairProjectCode(item.getWxxmh());
			v.setRemark(item.getWxxm());
			v.setRepairProjectType(repairProjectType);
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addres.add(v);
		}
	}

	public void addItfTblWxWxxmjcDownload(String synTaskNo, JSONArray jsonArray,Brand brandRec){
		List<ItfTblWxWxxmjcDownload> addRec = new ArrayList<>();
		List<ItfTblWxWxxmjcDownload> upRec = new ArrayList<>();
		List<RepairProject> addres = new ArrayList<>();
		List<RepairProject> upres = new ArrayList<>();

		getItfTblWxWxxmjcDownload(synTaskNo, jsonArray, addRec, upRec);

		if (addRec.size()>0){
			getAddRepairProject(brandRec, addRec, addres);
		}
		if (upRec.size()>0){
			getUpRepairProject(addRec, upRec, upres);
		}

		// 新增的插入到表
		if (addRec.size()>0){
			itfTblWxWxxmjcDownloadService.saveBatch(addRec);
			log.info("维修项目基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
		if (addres.size()>0){
			repairProjectService.saveBatch(addres);
			log.info("维修项目基表信息同步新增插入了{}条数据", addres.size());
			addres.clear();
		}

		if (upRec.size()>0){
			itfTblWxWxxmjcDownloadService.updateBatchById(upRec);
			log.info("维修项目基表信息同步修改了{}条数据", upRec.size());
			upRec.clear();
		}
		if (upres.size()>0){
			repairProjectService.updateBatchById(upres);
			log.info("维修项目信息同步修改了{}条数据", upres.size());
			upres.clear();
		}
	}

	public void addItfJhAzdCauseSortNewDownload(String synTaskNo, JSONArray jsonArray,Brand brandRec){
		List<ItfJhAzdCauseSortNewDownload> addRec = new ArrayList<>();
		getItfJhAzdCauseSortNewDownloadT(synTaskNo, jsonArray, addRec);

		// 新增冰箱故障固定为两级
		if (addRec.size()>0){
			getAddRepairBugJH(brandRec, addRec);
		}

		// 新增的插入到表 维修－产品故障基表下载记录
		if (addRec.size()>0){
			itfJhAzdCauseSortNewDownloadService.saveBatch(addRec);
			log.info("晶弘冰箱故障代码信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
	}

	public void addItfJhAzdCauseAtterDownload(String synTaskNo, JSONArray jsonArray,Brand brandRec){
		List<ItfJhAzdCauseAtterDownload> addRec = new ArrayList<>();
		List<RepairProject> addres = new ArrayList<>();

		getItfJhAzdCauseAtterDownload(synTaskNo, jsonArray, addRec);

		if (addRec.size()>0){
			getAddRepairProjectJH(brandRec, addRec, addres);
		}

		// 新增的插入到表
		if (addRec.size()>0){
			itfJhAzdCauseAtterDownloadService.saveBatch(addRec);
			log.info("晶弘冰箱维修项目基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
		if (addres.size()>0){
			repairProjectService.saveBatch(addres);
			log.info("晶弘冰箱维修项目基表信息同步新增插入了{}条数据", addres.size());
			addres.clear();
		}

	}


	public void addItfTblWxCpgzXjdDownload(String synTaskNo, JSONArray jsonArray,Brand brandRec){
		List<ItfTblWxCpgzXjdDownload> addRec = new ArrayList<>();
		List<ItfTblWxCpgzXjdDownload> upRec = new ArrayList<>();
		List<RepairBug> addRepairBug = new ArrayList<>();
		List<RepairBug> upRepairBug = new ArrayList<>();
		getItfTblWxCpgzXjdDownload(synTaskNo, jsonArray, addRec, upRec);

		// 新增
		if (addRec.size()>0){
			getAddRepairBugXJD(brandRec, addRec, addRepairBug);
		}
		// 修改
		if (upRec.size()>0){
			getUpRepairBugXJD(upRec, upRepairBug);
		}

		// 新增的插入到表 维修－产品故障基表下载记录
		if (addRec.size()>0){
			itfTblWxCpgzXjdDownloadService.saveBatch(addRec);
			log.info("生活电话故障代码信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
		if (addRepairBug.size()>0){
			repairBugService.saveBatch(addRepairBug);
			log.info("生活电话故障代码信息同步新增插入了{}条数据", addRepairBug.size());
			addRepairBug.clear();
		}

		if (upRec.size()>0){
			itfTblWxCpgzXjdDownloadService.updateBatchById(upRec);
			log.info("生活电话故障代码信息同步修改了{}条数据", upRec.size());
			upRec.clear();
		}

		if (upRepairBug.size()>0){
			repairBugService.updateBatchById(upRepairBug);
			log.info("生活电话故障代码信息同步修改了{}条数据", upRepairBug.size());
			upRepairBug.clear();
		}
	}

	public void addItfTblWxWxxmXjdDownload(String synTaskNo, JSONArray jsonArray,Brand brandRec){
		List<ItfTblWxWxxmXjdDownload> addRec = new ArrayList<>();
		List<ItfTblWxWxxmXjdDownload> upRec = new ArrayList<>();
		List<RepairProject> addres = new ArrayList<>();
		List<RepairProject> upres = new ArrayList<>();


		getItfTblWxWxxmXjdDownload(synTaskNo, jsonArray, addRec, upRec);

		if (addRec.size()>0){
			getAddRepairProjectXJD(brandRec, addRec, addres);
		}
		if (upRec.size()>0){
			getUpRepairProjectXJD(addRec, upRec, upres);
		}

		// 新增的插入到表
		if (addRec.size()>0){
			itfTblWxWxxmXjdDownloadService.saveBatch(addRec);
			log.info("晶弘冰箱维修项目基表信息同步新增插入了{}条数据", addRec.size());
			addRec.clear();
		}
		if (addres.size()>0){
			repairProjectService.saveBatch(addres);
			log.info("晶弘冰箱维修项目基表信息同步新增插入了{}条数据", addres.size());
			addres.clear();
		}

		if (upRec.size()>0){
			itfTblWxWxxmXjdDownloadService.updateBatchById(upRec);
			log.info("晶弘冰箱维修项目基表信息同步修改了{}条数据", upRec.size());
			upRec.clear();
		}
		if (upres.size()>0){
			repairProjectService.updateBatchById(upres);
			log.info("晶弘冰箱维修项目信息同步修改了{}条数据", upres.size());
			upres.clear();
		}
	}


	private void getAddRepairBug(Brand brandRec, List<ItfTblWxCpgzDownload> addRec, List<RepairBug> addRepairBug) {
		for (ItfTblWxCpgzDownload item: addRec){
			if (item.getShux().equals("通用")){
				continue;
			}
			if (StringUtils.isEmpty(item.getMshu())){
				continue;
			}
			RepairBug v = new RepairBug();
			v.setBugId(UUID.randomUUID().toString());
			v.setGzid(String.valueOf(item.getId()));
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setMainId(item.getCpdl());
			v.setSmallId(item.getCpxl());
			v.setMainFlag(item.getShux());
			v.setBugObj(item.getMshu());
			if (v.getBugObj().length()>2 &&
					v.getBugObj().substring(v.getBugObj().length()-2,v.getBugObj().length()).equals("--")){
				v.setBugObj(item.getMshu().substring(0,v.getBugObj().length()-2));
			}
			if (v.getBugObj().length()>1 &&
					v.getBugObj().substring(v.getBugObj().length()-1,v.getBugObj().length()).equals("-")){
				v.setBugObj(item.getMshu().substring(0,v.getBugObj().length()-1));
			}

			v.setBugObjCode(item.getXxyyh());
			v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addRepairBug.add(v);
		}
	}

	private void getAddRepairBugT(Brand brandRec, List<ItfTblWxCpgzDownload> addRec, List<RepairBug> addRepairBug) {
		String q = "-";
		for (ItfTblWxCpgzDownload item: addRec){
			if (item.getShux().equals("家用") || item.getShux().equals("通用")){
				String mshu = trim(item.getMshu());
				// 去掉右则-
				if (mshu.length()>2 &&
						mshu.substring(mshu.length()-2,mshu.length()).equals("--")){
					mshu = item.getMshu().substring(0,mshu.length()-2);
				}
				if (mshu.length()>1 &&
						mshu.substring(mshu.length()-1,mshu.length()).equals("-")){
					mshu = item.getMshu().substring(0,mshu.length()-1);
				}

				// 无层级关系
				if (!mshu.contains(q)){
					getAddRepairBug(brandRec, addRepairBug, item, mshu);
				} else {
					getAddrepairBugParent(brandRec, addRepairBug, q, item, mshu);
				}
			}
		}
	}

	private void getAddRepairBugSY(Brand brandRec, List<ItfTblWxCpgzDownload> addRec, List<RepairBug> addRepairBug) {
		String q = "-";
		for (ItfTblWxCpgzDownload item: addRec){
			if (!(item.getShux().equals("商用") || item.getShux().equals("通用"))){
				continue;
			}
			String mshu = trim(item.getMshu());
			if (mshu.length()>2 &&
					mshu.substring(mshu.length()-2,mshu.length()).equals("--")){
				mshu = item.getMshu().substring(0,mshu.length()-2);
			}
			if (mshu.length()>1 &&
					mshu.substring(mshu.length()-1,mshu.length()).equals("-")){
				mshu = item.getMshu().substring(0,mshu.length()-1);
			}

			// 无层级关系
			if (!mshu.contains(q)){
				getAddRepairBugSY(brandRec, addRepairBug, item, mshu);
			} else {
				getAddrepairBugParentSY(brandRec, addRepairBug, q, item, mshu);
			}
		}
	}

	private void getAddrepairBugParent(Brand brandRec, List<RepairBug> addRepairBug, String q, ItfTblWxCpgzDownload item, String mshu) {
		String[] result = mshu.split(q);
		String bugId="0";
		String parentPathName = "";
		for (int i=0;i<result.length;i++){
			if (i == result.length-1){
				// 查看是否存在，已存在不处理
				List<RepairBug> oldBugs = repairBugService.lambdaQuery()
						.eq(RepairBug::getBugObjType,1)
						.eq(RepairBug::getBugObjCode, item.getXxyyh())
						.eq(RepairBug::getLevel,1)
						.ne(RepairBug::getBugObjCode,"").list();
				if (CollectionUtils.isNotEmpty(oldBugs)){
					bugId = oldBugs.get(0).getBugId();
					continue;
				}
			} else {
				// 查看是否存在，已存在不处理
				List<RepairBug> oldBugs = repairBugService.lambdaQuery()
						.eq(RepairBug::getBugObjType,1)
						.eq(RepairBug::getBugObj,result[i])
						.eq(RepairBug::getBugObjCode,"")
						.eq(RepairBug::getParentPathName,parentPathName).list();
				if (CollectionUtils.isNotEmpty(oldBugs)){
					if (StringUtils.isEmpty(oldBugs.get(0).getParentPathName())){
						parentPathName="`" + oldBugs.get(0).getBugObj()+"`";
					} else {
						parentPathName=oldBugs.get(0).getParentPathName() + ",`" + oldBugs.get(0).getBugObj()+"`";
					}
					bugId = oldBugs.get(0).getBugId();
					continue;
				}
			}
			RepairBug v = new RepairBug();
			v.setBugId(UUID.randomUUID().toString());
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setMainId(item.getCpdl());
			v.setSmallId(item.getCpxl());
			v.setBugObj(result[i]);
			v.setParentId(bugId);
			bugId = v.getBugId();
			v.setBugObjCode("");
			if (i == result.length-1){
				v.setBugObjCode(item.getXxyyh());
			}
			v.setBugObjType(1);
			v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}
			v.setGzid(String.valueOf(item.getId()));
			v.setLevel(i+1);
			v.setParentPathName(parentPathName);
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			// addRepairBug.add(v);
			repairBugService.save(v);

			if (StringUtils.isEmpty(parentPathName)){
				parentPathName="`" + result[i]+"`";
			} else {
				parentPathName=parentPathName + ",`" + result[i]+"`";
			}
		}
	}

	private void getAddrepairBugParentSY(Brand brandRec, List<RepairBug> addRepairBug, String q, ItfTblWxCpgzDownload item, String mshu) {
		String[] result = mshu.split(q);
		String bugId="0";
		String parentPathName = "";
		for (int i=0;i<result.length;i++){
			if (i == result.length-1){
				// 查看是否存在，已存在不处理
				List<RepairBug> oldBugs = repairBugService.lambdaQuery()
						.eq(RepairBug::getBugObjType,2)
						.eq(RepairBug::getBugObjCode,item.getXxyyh())
						.gt(RepairBug::getLevel,0)
						.ne(RepairBug::getBugObjCode,"").list();
				if (CollectionUtils.isNotEmpty(oldBugs)){
					bugId = oldBugs.get(0).getBugId();
					continue;
				}
			} else {
				// 查看是否存在，已存在不处理
				List<RepairBug> oldBugs = repairBugService.lambdaQuery()
						.eq(RepairBug::getBugObjType,2)
						.eq(RepairBug::getBugObj,result[i])
						.eq(RepairBug::getBugObjCode,"")
						.eq(RepairBug::getParentPathName,parentPathName).list();
				if (CollectionUtils.isNotEmpty(oldBugs)){
					if (StringUtils.isEmpty(oldBugs.get(0).getParentPathName())){
						parentPathName="`" + oldBugs.get(0).getBugObj()+"`";
					} else {
						parentPathName=oldBugs.get(0).getParentPathName() + ",`" + oldBugs.get(0).getBugObj()+"`";
					}
					bugId = oldBugs.get(0).getBugId();
					continue;
				}
			}

			RepairBug v = new RepairBug();
			v.setBugId(UUID.randomUUID().toString());
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setMainId(item.getCpdl());
			v.setSmallId(item.getCpxl());
			v.setBugObj(result[i]);
			v.setParentId(bugId);
			bugId = v.getBugId();
			v.setBugObjCode("");
			if (i == result.length-1){
				v.setBugObjCode(item.getXxyyh());
			}
			v.setBugObjType(2);
			v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}
			v.setGzid(String.valueOf(item.getId()));
			v.setLevel(i+1);
			v.setParentPathName(parentPathName);
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			// addRepairBug.add(v);
			repairBugService.save(v);

			if (StringUtils.isEmpty(parentPathName)){
				parentPathName="`" + result[i]+"`";
			} else {
				parentPathName=parentPathName + ",`" + result[i]+"`";
			}
		}
	}

	private String getaddRepairBugT(Brand brandRec, List<RepairBug> addRepairBug, ItfTblWxCpgzDownload item, String[] result, String bugId, int i) {
		RepairBug v = new RepairBug();
		v.setBugId(UUID.randomUUID().toString());
		v.setBrandId(brandRec.getBrandId());
		v.setBrandName(brandRec.getBrand());
		v.setMainId(item.getCpdl());
		v.setSmallId(item.getCpxl());
		v.setBugObj(result[i]);
		v.setParentId(bugId);
		bugId = v.getBugId();
		v.setBugObjCode("");
		if (i == result.length-1){
			v.setBugObjCode(item.getXxyyh());
		}
		v.setBugObjType(1);
		v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
		if (item.getSfyx().equals(1L)){
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
		}
		v.setGzid(String.valueOf(item.getId()));
		v.setCreateBy("system");
		v.setCreateTime(new Date());
		if (item.getCreatedBy() !=null){
			v.setCreateBy(item.getCreatedBy());
		}
		if (item.getCreatedDate() != null){
			v.setCreateTime(item.getCreatedDate());
		}
		addRepairBug.add(v);
		return bugId;
	}

	private String getaddRepairBugTTow(Brand brandRec, List<RepairBug> addRepairBug, ItfTblWxCpgzDownload item, String[] result, String bugId, int i) {
		RepairBug v = new RepairBug();
		v.setBugId(UUID.randomUUID().toString());
		v.setBrandId(brandRec.getBrandId());
		v.setBrandName(brandRec.getBrand());
		v.setMainId(item.getCpdl());
		v.setSmallId(item.getCpxl());
		v.setBugObj(result[i]);
		v.setParentId(bugId);
		bugId = v.getBugId();
		v.setBugObjCode("");
		if (i == result.length-1){
			v.setBugObjCode(item.getXxyyh());
		}
		v.setBugObjType(2);
		v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
		if (item.getSfyx().equals(1L)){
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
		}
		v.setGzid(String.valueOf(item.getId()));
		v.setCreateBy("system");
		v.setCreateTime(new Date());
		if (item.getCreatedBy() !=null){
			v.setCreateBy(item.getCreatedBy());
		}
		if (item.getCreatedDate() != null){
			v.setCreateTime(item.getCreatedDate());
		}
		addRepairBug.add(v);
		return bugId;
	}

	private void getAddRepairBug(Brand brandRec, List<RepairBug> addRepairBug, ItfTblWxCpgzDownload item, String mshu) {
		// 查看是否存在，已存在不处理
		List<RepairBug> oldBugs = repairBugService.lambdaQuery()
				.eq(RepairBug::getBugObjType,1)
				.eq(RepairBug::getBugObjCode,item.getXxyyh())
				.eq(RepairBug::getLevel,1)
				.ne(RepairBug::getBugObjCode,"").list();
		if (CollectionUtils.isNotEmpty(oldBugs)){
			return;
		}

		RepairBug v = new RepairBug();
		v.setBugId(UUID.randomUUID().toString());
		v.setBrandId(brandRec.getBrandId());
		v.setParentId("0");
		v.setBrandName(brandRec.getBrand());
		v.setMainId(item.getCpdl());
		v.setSmallId(item.getCpxl());
		v.setBugObj(mshu);
		v.setBugObjType(1);
		v.setBugObjCode(item.getXxyyh());
		v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
		if (item.getSfyx().equals(1L)){
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
		}
		v.setGzid(String.valueOf(item.getId()));
		v.setParentPathName("");
		v.setLevel(1);
		v.setCreateBy("system");
		v.setCreateTime(new Date());
		if (item.getCreatedBy() !=null){
			v.setCreateBy(item.getCreatedBy());
		}
		if (item.getCreatedDate() != null){
			v.setCreateTime(item.getCreatedDate());
		}
		// addRepairBug.add(v);
		repairBugService.save(v);
	}

	private void getAddRepairBugSY(Brand brandRec, List<RepairBug> addRepairBug, ItfTblWxCpgzDownload item, String mshu) {
		// 查看是否存在，已存在不处理
		List<RepairBug> oldBugs = repairBugService.lambdaQuery()
				.eq(RepairBug::getBugObjType,2)
				.eq(RepairBug::getBugObjCode,item.getXxyyh())
				.gt(RepairBug::getLevel,0)
				.ne(RepairBug::getBugObjCode,"").list();
		if (CollectionUtils.isNotEmpty(oldBugs)){
			return;
		}

		RepairBug v = new RepairBug();
		v.setBugId(UUID.randomUUID().toString());
		v.setBrandId(brandRec.getBrandId());
		v.setParentId("0");
		v.setBrandName(brandRec.getBrand());
		v.setMainId(item.getCpdl());
		v.setSmallId(item.getCpxl());
		v.setBugObj(mshu);
		v.setBugObjType(2);
		v.setBugObjCode(item.getXxyyh());
		v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
		if (item.getSfyx().equals(1L)){
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
		}
		v.setGzid(String.valueOf(item.getId()));
		v.setParentPathName("");
		v.setLevel(1);
		v.setCreateBy("system");
		v.setCreateTime(new Date());
		if (item.getCreatedBy() !=null){
			v.setCreateBy(item.getCreatedBy());
		}
		if (item.getCreatedDate() != null){
			v.setCreateTime(item.getCreatedDate());
		}
		// addRepairBug.add(v);
		repairBugService.save(v);
	}

	private void getAddRepairBugTow(Brand brandRec, List<RepairBug> addRepairBug, ItfTblWxCpgzDownload item, String mshu) {
		RepairBug v = new RepairBug();
		v.setBugId(UUID.randomUUID().toString());
		v.setBrandId(brandRec.getBrandId());
		v.setParentId("0");
		v.setBrandName(brandRec.getBrand());
		v.setMainId(item.getCpdl());
		v.setSmallId(item.getCpxl());
		v.setBugObj(mshu);
		v.setBugObjType(1);
		v.setBugObjCode(item.getXxyyh());
		v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
		if (item.getSfyx().equals(1L)){
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
		}
		v.setGzid(String.valueOf(item.getId()));
		v.setCreateBy("system");
		v.setCreateTime(new Date());
		if (item.getCreatedBy() !=null){
			v.setCreateBy(item.getCreatedBy());
		}
		if (item.getCreatedDate() != null){
			v.setCreateTime(item.getCreatedDate());
		}
		addRepairBug.add(v);
		repairBugService.save(v);
		RepairBug t = new RepairBug();
		MyBeanUtils.copyProperties(v,t);
		t.setBugId(UUID.randomUUID().toString());
		v.setBugObjType(2);
		addRepairBug.add(t);
		repairBugService.save(t);
	}

	private void getAddRepairBugTY(Brand brandRec, List<ItfTblWxCpgzDownload> addRec, List<RepairBug> addRepairBug) {
		for (ItfTblWxCpgzDownload item: addRec){
			if (!item.getShux().equals("通用")){
				continue;
			}
			if (StringUtils.isEmpty(item.getMshu())){
				continue;
			}

			RepairBug v = new RepairBug();
			v.setBugId(UUID.randomUUID().toString());
			v.setGzid(String.valueOf(item.getId()));
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setMainFlag("家用");
			v.setMainId(item.getCpdl());
			v.setSmallId(item.getCpxl());
			v.setBugObj(item.getMshu());
			if (v.getBugObj().length()>2 &&
					v.getBugObj().substring(v.getBugObj().length()-2,v.getBugObj().length()).equals("--")){
				v.setBugObj(item.getMshu().substring(0,v.getBugObj().length()-2));
			}
			if (v.getBugObj().length()>1 &&
					v.getBugObj().substring(v.getBugObj().length()-1,v.getBugObj().length()).equals("-")){
				v.setBugObj(item.getMshu().substring(0,v.getBugObj().length()-1));
			}

			v.setBugObjCode(item.getXxyyh());
			v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addRepairBug.add(v);
			RepairBug t = new RepairBug();
			MyBeanUtils.copyProperties(v,t);
			t.setBugId(UUID.randomUUID().toString());
			t.setMainFlag("商用");
			addRepairBug.add(t);
		}
	}

	private void getAddRepairBugTYT(Brand brandRec, List<ItfTblWxCpgzDownload> addRec, List<RepairBug> addRepairBug) {
		String q = "-";
		for (ItfTblWxCpgzDownload item: addRec){
			if (!item.getShux().equals("通用")){
				continue;
			}
			String mshu = trim(item.getMshu());
			if (mshu.length()>2 &&
					mshu.substring(mshu.length()-2,mshu.length()).equals("--")){
				mshu = item.getMshu().substring(0,mshu.length()-2);
			}
			if (mshu.length()>1 &&
					mshu.substring(mshu.length()-1,mshu.length()).equals("-")){
				mshu = item.getMshu().substring(0,mshu.length()-1);
			}
			// 无层级关系
			if (!mshu.contains(q)){
				getAddRepairBugTow(brandRec, addRepairBug, item, mshu);
			} else {
				String[] result = mshu.split(q);
				String bugId="0";
				for (int i=0;i<result.length;i++){
					bugId = getaddRepairBugT(brandRec, addRepairBug, item, result, bugId, i);
				}
				bugId="0";
				for (int i=0;i<result.length;i++){
					bugId = getaddRepairBugTTow(brandRec, addRepairBug, item, result, bugId, i);
				}
			}
		}
	}

	public void getAddRepairBugJH(Brand brandRec, List<ItfJhAzdCauseSortNewDownload> addRec) {
		String parentPathName = "";
		String pid="0";
		List<RepairBug> rblist = new ArrayList<>();
		for (ItfJhAzdCauseSortNewDownload item: addRec){
			pid="0";
			List<RepairBug> rb = repairBugService.lambdaQuery()
					.eq(RepairBug::getBugObjType,5)
					.eq(RepairBug::getBugObj,item.getSort()).list();
			if (CollectionUtils.isEmpty(rb)){
				RepairBug o = new RepairBug();
				o.setBugId(UUID.randomUUID().toString());
				o.setGzid(String.valueOf(item.getId()));
				o.setBrandId(brandRec.getBrandId());
				o.setBrandName(brandRec.getBrand());
				o.setMainFlag("5");
				o.setMainName("");
				o.setMainId("");
				o.setSmallName("");
				o.setSmallId("");
				o.setBugObj(item.getSort());
				o.setBugObjCode("");
				o.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
				if (item.getStatus().equals(1L)){
					o.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
				}

				o.setParentId(pid);
				pid=o.getBugId();
				o.setParentPathName("");
				o.setLevel(0);

				o.setCreateBy("system");
				o.setCreateTime(new Date());
				if (item.getCreatedBy() !=null){
					o.setCreateBy(item.getCreatedBy());
				}
				if (item.getCreatedDate() != null){
					o.setCreateTime(item.getCreatedDate());
				}
				rblist.add(o);
				parentPathName="`" + item.getSort() +"`";
			} else {
				parentPathName="`" + rb.get(0).getBugObj() +"`";
				pid = rb.get(0).getBugId();
			}

			List<RepairBug> rbs = repairBugService.lambdaQuery()
					.eq(RepairBug::getBugObjType,5)
					.eq(RepairBug::getBugObj,item.getDescription()).list();
			if (CollectionUtils.isEmpty(rbs)){
				RepairBug v = new RepairBug();
				v.setBugId(UUID.randomUUID().toString());
				v.setGzid(String.valueOf(item.getId()));
				v.setBrandId(brandRec.getBrandId());
				v.setBrandName(brandRec.getBrand());
				v.setMainFlag("5");
				v.setMainName("");
				v.setMainId("");
				v.setSmallName("");
				v.setSmallId("");
				v.setBugObj(item.getDescription());
				v.setBugObjCode(item.getCauseno());
				v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
				if (item.getStatus().equals(1L)){
					v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
				}

				v.setParentId(pid);
				v.setParentPathName(parentPathName);
				v.setLevel(0);

				v.setCreateBy("system");
				v.setCreateTime(new Date());
				if (item.getCreatedBy() !=null){
					v.setCreateBy(item.getCreatedBy());
				}
				if (item.getCreatedDate() != null){
					v.setCreateTime(item.getCreatedDate());
				}
				rblist.add(v);
			}

			if (rblist.size()>0){
				repairBugService.saveBatch(rblist);
				rblist.clear();
			}
		}
	}

	private void getAddRepairBugJHOld(Brand brandRec, List<ItfJhAzdCauseSortNewDownload> addRec,
								   List<RepairBug> addRepairBug) {
		for (ItfJhAzdCauseSortNewDownload item: addRec){
			RepairBug v = new RepairBug();
			v.setBugId(UUID.randomUUID().toString());
			v.setGzid(String.valueOf(item.getId()));
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setMainFlag("5");
			v.setMainName("");
			v.setMainId("");
			v.setSmallName("");
			v.setSmallId("");
			v.setBugObj(item.getDescription());
			v.setBugObjCode(item.getCauseno());
			v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getStatus().equals(1L)){
				v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}

			v.setParentId("0");
			v.setParentPathName("");
			v.setLevel(1);

			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addRepairBug.add(v);
		}
	}

	private void getAddRepairBugXJD(Brand brandRec, List<ItfTblWxCpgzXjdDownload> addRec, List<RepairBug> addRepairBug) {
		for (ItfTblWxCpgzXjdDownload item: addRec){
			RepairBug v = new RepairBug();
			v.setBugId(UUID.randomUUID().toString());
			v.setGzid(String.valueOf(item.getId()));
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setMainFlag("生活电器");
			v.setMainName("");
			v.setMainId("");
			v.setSmallName("");
			v.setSmallId("");
			v.setBugObj(item.getGzms());
			v.setBugObjCode(item.getGzdm());
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addRepairBug.add(v);
		}
	}

	private void getUpRepairBug(List<ItfTblWxCpgzDownload> upRec, List<RepairBug> upRepairBug) {
		List<String> gzid = new ArrayList<>();
		upRec.forEach(i->{
			gzid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairBug> rbs = repairBugService.lambdaQuery()
				.in(RepairBug::getGzid,gzid)
				.eq(RepairBug::getMainFlag,"家用").list();
		Map<String,List<RepairBug>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairBug::getGzid));

		for (ItfTblWxCpgzDownload item: upRec){
			if (!rbsMap.containsKey(item.getId())){
				continue;
			}
			if (StringUtils.isEmpty(item.getMshu())){
				continue;
			}

			RepairBug u = new RepairBug();
			u = rbsMap.get(item.getId()).get(0);
			u.setMainFlag(item.getShux());
			u.setMainId(item.getCpdl());
			u.setSmallId(item.getCpxl());
			u.setBugObj(item.getMshu());
			if (u.getBugObj().length()>2 &&
					u.getBugObj().substring(u.getBugObj().length()-2,u.getBugObj().length()).equals("--")){
				u.setBugObj(item.getMshu().substring(0,u.getBugObj().length()-2));
			}
			if (u.getBugObj().length()>1 &&
					u.getBugObj().substring(u.getBugObj().length()-1,u.getBugObj().length()).equals("-")){
				u.setBugObj(item.getMshu().substring(0,u.getBugObj().length()-1));
			}

			u.setBugObjCode(item.getXxyyh());
			u.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				u.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}

			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upRepairBug.add(u);
		}
	}
	private void getUpRepairBugSY(List<ItfTblWxCpgzDownload> upRec, List<RepairBug> upRepairBug) {
		List<String> gzid = new ArrayList<>();
		upRec.forEach(i->{
			gzid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairBug> rbs = repairBugService.lambdaQuery()
				.in(RepairBug::getGzid,gzid)
				.eq(RepairBug::getMainFlag,"商用").list();
		Map<String,List<RepairBug>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairBug::getGzid));

		for (ItfTblWxCpgzDownload item: upRec){
			if (!rbsMap.containsKey(item.getId())){
				continue;
			}
			if (StringUtils.isEmpty(item.getMshu())){
				continue;
			}

			RepairBug u = new RepairBug();
			u = rbsMap.get(item.getId()).get(0);
			u.setMainFlag(item.getShux());
			u.setMainId(item.getCpdl());
			u.setSmallId(item.getCpxl());
			u.setBugObj(item.getMshu());
			if (u.getBugObj().length()>2 &&
					u.getBugObj().substring(u.getBugObj().length()-2,u.getBugObj().length()).equals("--")){
				u.setBugObj(item.getMshu().substring(0,u.getBugObj().length()-2));
			}
			if (u.getBugObj().length()>1 &&
					u.getBugObj().substring(u.getBugObj().length()-1,u.getBugObj().length()).equals("-")){
				u.setBugObj(item.getMshu().substring(0,u.getBugObj().length()-1));
			}

			u.setBugObjCode(item.getXxyyh());
			u.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				u.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}

			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upRepairBug.add(u);
		}
	}

	private void getUpRepairBugJH(List<ItfJhAzdCauseSortNewDownload> upRec, List<RepairBug> upRepairBug) {
		List<String> gzid = new ArrayList<>();
		upRec.forEach(i->{
			gzid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairBug> rbs = repairBugService.lambdaQuery()
				.eq(RepairBug::getMainFlag,"晶弘冰箱")
				.in(RepairBug::getGzid,gzid).list();
		Map<String,List<RepairBug>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairBug::getGzid));

		for (ItfJhAzdCauseSortNewDownload item: upRec){
			RepairBug u = new RepairBug();
			u = rbsMap.get(item.getId()).get(0);
			u.setBugObj(item.getDescription());
			u.setBugObjCode(item.getCauseno());
			u.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getStatus().equals(1L)){
				u.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}

			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upRepairBug.add(u);
		}
	}

	private void getUpRepairBugXJD(List<ItfTblWxCpgzXjdDownload> upRec, List<RepairBug> upRepairBug) {
		List<String> gzid = new ArrayList<>();
		upRec.forEach(i->{
			gzid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairBug> rbs = repairBugService.lambdaQuery()
				.eq(RepairBug::getMainFlag,"生活电器")
				.in(RepairBug::getGzid,gzid).list();
		Map<String,List<RepairBug>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairBug::getGzid));

		for (ItfTblWxCpgzXjdDownload item: upRec){
			RepairBug u = new RepairBug();
			u = rbsMap.get(item.getId()).get(0);
			u.setBugObj(item.getGzms());
			u.setBugObjCode(item.getGzdm());
			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upRepairBug.add(u);
		}
	}

	private void getAddRepairProject(Brand brandRec, List<ItfTblWxWxxmjcDownload> addRec, List<RepairProject> addres) {
		// 按项目分类分组，只取其一
		List<String> xmfls = new ArrayList<>();
		for (ItfTblWxWxxmjcDownload item: addRec){
			if (xmfls.contains(item.getXmfl())){
				continue;
			}
			xmfls.add(item.getXmfl());
			RepairProject v = new RepairProject();
			v.setRepairProjectId(IdWorker.getIdStr());
			v.setOutXmId(item.getId());
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setRepairProjectCode(item.getWxxmh());
			v.setBugObjCode("");
			v.setRemark(item.getXmfl());
			v.setRepairProjectType("商用空调");
			v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addres.add(v);
		}
	}

	private void getAddRepairProjectJH(Brand brandRec, List<ItfJhAzdCauseAtterDownload> addRec, List<RepairProject> addres) {
		// 提取现有的数据
		List<RepairProject> rbs = repairProjectService.lambdaQuery()
				.eq(RepairProject::getRepairProjectType,"4").list();
		Map<String,List<RepairProject>> rbsMap = rbs.stream().
				collect(Collectors.groupingBy(RepairProject::getRepairProjectCode));

		for (ItfJhAzdCauseAtterDownload item: addRec){
			// 已存在不处理
			if (rbsMap.containsKey(item.getAtterno())){
				for (RepairProject i :rbsMap.get(item.getAtterno())){
					if (i.getBugObjCode().equals(item.getCauseno())){
						continue;
					}
				}
			}
			RepairProject v = new RepairProject();
			v.setRepairProjectId(IdWorker.getIdStr());
			v.setOutId(item.getId());
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setBugObjCode(item.getCauseno());
			v.setRepairProjectCode(item.getAtterno());
			v.setRemark(item.getAtter());
			v.setRepairProjectType("晶弘冰箱");
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addres.add(v);
		}
	}

	private void getAddRepairProjectJHOld(Brand brandRec, List<ItfJhAzdCauseAtterDownload> addRec, List<RepairProject> addres) {
		for (ItfJhAzdCauseAtterDownload item: addRec){
			RepairProject v = new RepairProject();
			v.setRepairProjectId(IdWorker.getIdStr());
			v.setOutId(item.getId());
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setBugObjCode(item.getCauseno());
			v.setRepairProjectCode(item.getAtterno());
			v.setRemark(item.getAtter());
			v.setRepairProjectType("晶弘冰箱");
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addres.add(v);
		}
	}

	private void getAddRepairProjectXJD(Brand brandRec, List<ItfTblWxWxxmXjdDownload> addRec, List<RepairProject> addres) {
		for (ItfTblWxWxxmXjdDownload item: addRec){
			RepairProject v = new RepairProject();
			v.setRepairProjectId(IdWorker.getIdStr());
			v.setOutId(Long.valueOf(item.getId()));
			v.setBrandId(brandRec.getBrandId());
			v.setBrandName(brandRec.getBrand());
			v.setBugObjCode("");
			v.setRepairProjectCode(item.getWxdm());
			v.setRemark(item.getCpdl());
			v.setRepairProjectType("生活电器");
			v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			v.setCreateBy("system");
			v.setCreateTime(new Date());
			if (item.getCreatedBy() !=null){
				v.setCreateBy(item.getCreatedBy());
			}
			if (item.getCreatedDate() != null){
				v.setCreateTime(item.getCreatedDate());
			}
			addres.add(v);
		}
	}

	private void getUpRepairProject(List<ItfTblWxWxxmjcDownload> addRec, List<ItfTblWxWxxmjcDownload> upRec, List<RepairProject> upres) {
		List<String> rpid = new ArrayList<>();
		upRec.forEach(i->{
			rpid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairProject> rbs = repairProjectService.lambdaQuery()
				.in(RepairProject::getOutXmId,rpid).list();
		Map<String,List<RepairProject>> rbsMap = rbs.stream().
				collect(Collectors.groupingBy(RepairProject::getOutXmId));

		for (ItfTblWxWxxmjcDownload item: addRec){
			if (!rbsMap.containsKey(item.getId())){
				continue;
			}
			RepairProject u = new RepairProject();
			u = rbsMap.get(item.getId()).get(0);
			u.setRepairProjectCode(item.getWxxmh());
			u.setRemark(item.getXmfl());
			u.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
			if (item.getSfyx().equals(1L)){
				u.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			}

			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upres.add(u);
		}
	}

	private void getUpRepairProjectJH(List<ItfJhAzdCauseAtterDownload> upRec, List<RepairProject> upres) {
		List<Long> rpid = new ArrayList<>();
		upRec.forEach(i->{
			rpid.add(i.getId());
		});
		// 提取现有的数据
		List<RepairProject> rbs = repairProjectService.lambdaQuery()
				.eq(RepairProject::getRepairProjectType,"晶弘冰箱")
				.in(RepairProject::getOutId,rpid).list();
		Map<Long,List<RepairProject>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairProject::getOutId));

		for (ItfJhAzdCauseAtterDownload item: upRec){
			RepairProject u = new RepairProject();
			u = rbsMap.get(item.getId()).get(0);
			u.setBugObjCode(item.getAtterno());
			u.setRepairProjectCode(item.getAtterno());
			u.setRemark(item.getAtter());
			u.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upres.add(u);
		}
	}

	private void getUpRepairProjectXJD(List<ItfTblWxWxxmXjdDownload> addRec, List<ItfTblWxWxxmXjdDownload> upRec, List<RepairProject> upres) {
		List<Long> rpid = new ArrayList<>();
		upRec.forEach(i->{
			rpid.add(Long.valueOf(i.getId()));
		});
		// 提取现有的数据
		List<RepairProject> rbs = repairProjectService.lambdaQuery()
				.in(RepairProject::getRepairProjectType,"生活电器")
				.in(RepairProject::getOutId,rpid).list();
		Map<Long,List<RepairProject>> rbsMap = rbs.stream().collect(Collectors.groupingBy(RepairProject::getOutId));

		for (ItfTblWxWxxmXjdDownload item: addRec){
			RepairProject u = new RepairProject();
			u = rbsMap.get(item.getId()).get(0);
			u.setRepairProjectCode(item.getWxdm());
			u.setRemark(item.getCpdl());
			u.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
			u.setUpdateTime(new Date());
			if (item.getLastModifiedBy() !=null){
				u.setUpdateBy(item.getLastModifiedBy());
			}
			if (item.getLastModifiedDate() != null){
				u.setUpdateTime(item.getLastModifiedDate());
			}
			upres.add(u);
		}
	}

	private void getItfTblWxCpgzDownload(String synTaskNo, JSONArray jsonArray,
										 List<ItfTblWxCpgzDownload> addRec,
										 List<ItfTblWxCpgzDownload> upRec) {
		List<ItfTblWxCpgzDownload> oldRec =  itfTblWxCpgzDownloadService.lambdaQuery().list();
		Map<String, List<ItfTblWxCpgzDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfTblWxCpgzDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxCpgzDownload item = JSON.toJavaObject(aData,ItfTblWxCpgzDownload.class);
			if (StringUtils.isEmpty(item.getXxyyh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getGzxx())){
				item.setGzxx("");
			}
			if (StringUtils.isEmpty(item.getMshu())){
				item.setMshu("");
			}
			if (StringUtils.isEmpty(item.getCpdl())){
				item.setCpdl("");
			}
			if (StringUtils.isEmpty(item.getCpxl())){
				item.setCpxl("");
			}
			if (StringUtils.isEmpty(item.getShux())){
				item.setShux("");
			}
			if (StringUtils.isEmpty(item.getGzxx())){
				item.setGzxx("");
			}
			if (StringUtils.isEmpty(item.getGzzyy())){
				item.setGzzyy("");
			}
			if (StringUtils.isEmpty(item.getGzfyy())){
				item.setGzfyy("");
			}

			if (oldRecMap.containsKey(item.getId())){
				ItfTblWxCpgzDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getMshu().equals(item.getMshu())){
					o.setMshu(item.getMshu());
					flag = Boolean.TRUE;
				}
				if (!o.getXxyyh().equals(item.getXxyyh())){
					o.setXxyyh(item.getXxyyh());
					flag = Boolean.TRUE;
				}
				if (!o.getSfyx().equals(item.getSfyx())){
					o.setSfyx(item.getSfyx());
					flag = Boolean.TRUE;
				}
				if (!o.getCpdl().equals(item.getCpdl())){
					o.setCpdl(item.getCpdl());
					flag = Boolean.TRUE;
				}
				if (!o.getCpxl().equals(item.getCpxl())){
					o.setCpxl(item.getCpxl());
					flag = Boolean.TRUE;
				}
				if (!o.getShux().equals(item.getShux())){
					o.setShux(item.getShux());
					flag = Boolean.TRUE;
				}
				if (!o.getGzxx().equals(item.getGzxx())){
					o.setGzxx(item.getGzxx());
					flag = Boolean.TRUE;
				}
				if (!o.getGzzyy().equals(item.getGzzyy())){
					o.setGzzyy(item.getGzzyy());
					flag = Boolean.TRUE;
				}
				if (!o.getGzfyy().equals(item.getGzfyy())){
					o.setGzfyy(item.getGzfyy());
					flag = Boolean.TRUE;
				}
				if (!o.getCpsx().equals(item.getCpsx())){
					o.setCpsx(item.getCpsx());
					flag = Boolean.TRUE;
				}
				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}


	private void getItfTblWxCpgzDownloadT(String synTaskNo, JSONArray jsonArray,
										 List<ItfTblWxCpgzDownload> addRec) {
		for (int i = 0; i < jsonArray.size(); i++) {
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxCpgzDownload item = JSON.toJavaObject(aData,ItfTblWxCpgzDownload.class);
			if (StringUtils.isEmpty(item.getXxyyh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getGzxx())){
				item.setGzxx("");
			}
			if (StringUtils.isEmpty(item.getMshu())){
				item.setMshu("");
			}
			if (StringUtils.isEmpty(item.getCpdl())){
				item.setCpdl("");
			}
			if (StringUtils.isEmpty(item.getCpxl())){
				item.setCpxl("");
			}
			if (StringUtils.isEmpty(item.getShux())){
				item.setShux("");
			}
			if (StringUtils.isEmpty(item.getGzxx())){
				item.setGzxx("");
			}
			if (StringUtils.isEmpty(item.getGzzyy())){
				item.setGzzyy("");
			}
			if (StringUtils.isEmpty(item.getGzfyy())){
				item.setGzfyy("");
			}

			item.setSynTaskNo(synTaskNo);
			item.setSynReqTime(new Date());
			item.setSynStatus(1);
			item.setSynTime(new Date());
			item.setSynTimes(0);
			addRec.add(item);
		}
	}

	private void getItfJhAzdCauseSortNewDownload(String synTaskNo, JSONArray jsonArray,
												 List<ItfJhAzdCauseSortNewDownload> addRec,
												 List<ItfJhAzdCauseSortNewDownload> upRec) {
		List<ItfJhAzdCauseSortNewDownload> oldRec =  itfJhAzdCauseSortNewDownloadService.lambdaQuery().list();
		Map<String, List<ItfJhAzdCauseSortNewDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfJhAzdCauseSortNewDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfJhAzdCauseSortNewDownload item = JSON.toJavaObject(aData,ItfJhAzdCauseSortNewDownload.class);
			if (StringUtils.isEmpty(item.getCauseno())){
				continue;
			}
			if (StringUtils.isEmpty(item.getDescription())){
				continue;
			}
			if (StringUtils.isEmpty(item.getSort())){
				item.setSort("");
			}

			if (oldRecMap.containsKey(item.getId())){
				ItfJhAzdCauseSortNewDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getCauseno().equals(item.getCauseno())){
					o.setCauseno(item.getCauseno());
					flag = Boolean.TRUE;
				}
				if (!o.getDescription().equals(item.getDescription())){
					o.setDescription(item.getDescription());
					flag = Boolean.TRUE;
				}
				if (!o.getSort().equals(item.getSort())){
					o.setSort(item.getSort());
					flag = Boolean.TRUE;
				}
				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}

	private void getItfJhAzdCauseSortNewDownloadT(String synTaskNo, JSONArray jsonArray,
												 List<ItfJhAzdCauseSortNewDownload> addRec) {
		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfJhAzdCauseSortNewDownload item = JSON.toJavaObject(aData,ItfJhAzdCauseSortNewDownload.class);
			if (StringUtils.isEmpty(item.getCauseno())){
				continue;
			}
			if (StringUtils.isEmpty(item.getDescription())){
				continue;
			}
			if (StringUtils.isEmpty(item.getSort())){
				item.setSort("");
			}

			item.setSynTaskNo(synTaskNo);
			item.setSynReqTime(new Date());
			item.setSynStatus(1);
			item.setSynTime(new Date());
			item.setSynTimes(0);
			addRec.add(item);
		}
	}

	private void getItfTblWxCpgzXjdDownload(String synTaskNo, JSONArray jsonArray,
											List<ItfTblWxCpgzXjdDownload> addRec,
											List<ItfTblWxCpgzXjdDownload> upRec) {
		List<ItfTblWxCpgzXjdDownload> oldRec =  itfTblWxCpgzXjdDownloadService.lambdaQuery().list();
		Map<String, List<ItfTblWxCpgzXjdDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfTblWxCpgzXjdDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxCpgzXjdDownload item = JSON.toJavaObject(aData,ItfTblWxCpgzXjdDownload.class);
			if (StringUtils.isEmpty(item.getGzdm())){
				continue;
			}
			if (StringUtils.isEmpty(item.getGzms())){
				continue;
			}
			if (oldRecMap.containsKey(item.getId())){
				ItfTblWxCpgzXjdDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getGzdm().equals(item.getGzdm())){
					o.setGzdm(item.getGzdm());
					flag = Boolean.TRUE;
				}
				if (!o.getGzms().equals(item.getGzms())){
					o.setGzms(item.getGzms());
					flag = Boolean.TRUE;
				}
				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}

	private void getItfTblWxGzdmWxxmjcDownload(String synTaskNo, JSONArray jsonArray,
											   List<ItfTblWxGzdmWxxmjcDownload> addRec,
											   List<ItfTblWxGzdmWxxmjcDownload> upRec) {
		List<ItfTblWxGzdmWxxmjcDownload> oldRec =  itfTblWxGzdmWxxmjcDownloadService.lambdaQuery().list();
		Map<String, List<ItfTblWxGzdmWxxmjcDownload>> oldRecMap = oldRec.stream().
				collect(Collectors.groupingBy(ItfTblWxGzdmWxxmjcDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxGzdmWxxmjcDownload item = JSON.toJavaObject(aData,ItfTblWxGzdmWxxmjcDownload.class);

			if (StringUtils.isEmpty(item.getWxxmh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getWxxm())){
				continue;
			}
			if (StringUtils.isEmpty(item.getXxyyh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getXxyyh())){
				continue;
			}
			if (item.getCpsx()==null){
				item.setCpsx(1);
			}
			if (item.getXxyy()==null){
				item.setXxyy("");
			}

			if (oldRecMap.containsKey(item.getId())){
				ItfTblWxGzdmWxxmjcDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getCpsx().equals(item.getCpsx())){
					o.setCpsx(item.getCpsx());
					flag = Boolean.TRUE;
				}
				if (!o.getWxxmh().equals(item.getWxxmh())){
					o.setWxxmh(item.getWxxmh());
					flag = Boolean.TRUE;
				}
				if (!o.getWxxm().equals(item.getWxxm())){
					o.setWxxm(item.getWxxm());
					flag = Boolean.TRUE;
				}
				if (!o.getXxyy().equals(item.getXxyy())){
					o.setXxyy(item.getXxyy());
					flag = Boolean.TRUE;
				}
				if (!o.getXxyyh().equals(item.getXxyyh())){
					o.setXxyyh(item.getXxyyh());
					flag = Boolean.TRUE;
				}
				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}

	private void getItfTblWxGzdmWxxmjcDownloadT(String synTaskNo, JSONArray jsonArray,
											   List<ItfTblWxGzdmWxxmjcDownload> addRec) {
		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxGzdmWxxmjcDownload item = JSON.toJavaObject(aData,ItfTblWxGzdmWxxmjcDownload.class);

			if (StringUtils.isEmpty(item.getWxxmh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getWxxm())){
				continue;
			}
			if (StringUtils.isEmpty(item.getXxyyh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getXxyyh())){
				continue;
			}
			if (item.getCpsx()==null){
				item.setCpsx(1);
			}
			if (item.getXxyy()==null){
				item.setXxyy("");
			}

			item.setSynTaskNo(synTaskNo);
			item.setSynReqTime(new Date());
			item.setSynStatus(1);
			item.setSynTime(new Date());
			item.setSynTimes(0);
			addRec.add(item);
		}
	}

	private void getItfTblWxWxxmjcDownload(String synTaskNo, JSONArray jsonArray,
										   List<ItfTblWxWxxmjcDownload> addRec,
										   List<ItfTblWxWxxmjcDownload> upRec) {
		List<ItfTblWxWxxmjcDownload> oldRec =  itfTblWxWxxmjcDownloadService.lambdaQuery()
				.orderByDesc(ItfTblWxWxxmjcDownload::getCzsj)
				.orderByDesc(ItfTblWxWxxmjcDownload::getId).list();
		Map<String, List<ItfTblWxWxxmjcDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfTblWxWxxmjcDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxWxxmjcDownload item = JSON.toJavaObject(aData,ItfTblWxWxxmjcDownload.class);
			if (StringUtils.isEmpty(item.getWxxmh())){
				continue;
			}
			if (StringUtils.isEmpty(item.getXmfl())){
				continue;
			}
			if (StringUtils.isEmpty(item.getMshu())){
				item.setMshu("");
			}
			if (StringUtils.isEmpty(item.getLeib())){
				item.setLeib("");
			}
			if (StringUtils.isEmpty(item.getLbsm())){
				item.setLbsm("");
			}
			if (StringUtils.isEmpty(item.getJdm())){
				item.setJdm("");
			}
			if (StringUtils.isEmpty(item.getLeib())){
				item.setLeib("");
			}
			if (StringUtils.isEmpty(item.getXmfl())){
				item.setXmfl("");
			}
			if (item.getKzzt()==null){
				item.setKzzt(0L);
			}
			if (item.getCjkz()==null){
				item.setCjkz(0L);
			}
			if (item.getSfyx()==null){
				item.setSfyx(1L);
			}
			if (item.getWgkz()==null){
				item.setWgkz(0L);
			}

			if (oldRecMap.containsKey(item.getId())){
				ItfTblWxWxxmjcDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getWxxmh().equals(item.getWxxmh())){
					o.setWxxmh(item.getWxxmh());
					flag = Boolean.TRUE;
				}
				if (!o.getXmfl().equals(item.getXmfl())){
					o.setXmfl(item.getXmfl());
					flag = Boolean.TRUE;
				}
				if (!o.getMshu().equals(item.getMshu())){
					o.setMshu(item.getMshu());
					flag = Boolean.TRUE;
				}
				if (!o.getGhpj().equals(item.getGhpj())){
					o.setGhpj(item.getGhpj());
					flag = Boolean.TRUE;
				}
				if (!o.getCpsx().equals(item.getCpsx())){
					o.setCpsx(item.getCpsx());
					flag = Boolean.TRUE;
				}
				if (!o.getLeib().equals(item.getLeib())){
					o.setLeib(item.getLeib());
					flag = Boolean.TRUE;
				}
				if (!o.getLbsm().equals(item.getLbsm())){
					o.setLbsm(item.getLbsm());
					flag = Boolean.TRUE;
				}
				if (!o.getKzzt().equals(item.getKzzt())){
					o.setKzzt(item.getKzzt());
					flag = Boolean.TRUE;
				}
				if (!o.getCjkz().equals(item.getCjkz())){
					o.setCjkz(item.getCjkz());
					flag = Boolean.TRUE;
				}
				if (!o.getJdm().equals(item.getJdm())){
					o.setJdm(item.getJdm());
					flag = Boolean.TRUE;
				}
				if (!o.getSfyx().equals(item.getSfyx())){
					o.setSfyx(item.getSfyx());
					flag = Boolean.TRUE;
				}
				if (!o.getWgkz().equals(item.getWgkz())){
					o.setWgkz(item.getWgkz());
					flag = Boolean.TRUE;
				}
				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}

	private void getItfJhAzdCauseAtterDownload(String synTaskNo, JSONArray jsonArray,
											   List<ItfJhAzdCauseAtterDownload> addRec) {
		for (int i = 0; i < jsonArray.size(); i++) {
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfJhAzdCauseAtterDownload item = JSON.toJavaObject(aData,ItfJhAzdCauseAtterDownload.class);
			if (StringUtils.isEmpty(item.getAtterno())){
				continue;
			}
			if (StringUtils.isEmpty(item.getAtter())){
				continue;
			}
			if (StringUtils.isEmpty(item.getCauseno())){
				item.setCauseno("");
			}
			if (StringUtils.isEmpty(item.getCause())){
				item.setCause("");
			}

			item.setSynTaskNo(synTaskNo);
			item.setSynReqTime(new Date());
			item.setSynStatus(1);
			item.setSynTime(new Date());
			item.setSynTimes(0);
			addRec.add(item);
		}
	}

	private void getItfJhAzdCauseAtterDownloadOld(String synTaskNo, JSONArray jsonArray,
											   List<ItfJhAzdCauseAtterDownload> addRec,
											   List<ItfJhAzdCauseAtterDownload> upRec) {
		List<ItfJhAzdCauseAtterDownload> oldRec =  itfJhAzdCauseAtterDownloadService.lambdaQuery().list();
		Map<Long, List<ItfJhAzdCauseAtterDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfJhAzdCauseAtterDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfJhAzdCauseAtterDownload item = JSON.toJavaObject(aData,ItfJhAzdCauseAtterDownload.class);
			if (StringUtils.isEmpty(item.getAtterno())){
				continue;
			}
			if (StringUtils.isEmpty(item.getAtter())){
				continue;
			}
			if (StringUtils.isEmpty(item.getCauseno())){
				item.setCauseno("");
			}
			if (StringUtils.isEmpty(item.getCause())){
				item.setCause("");
			}

			if (oldRecMap.containsKey(item.getId())){
				ItfJhAzdCauseAtterDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getAtterno().equals(item.getAtterno())){
					o.setAtterno(item.getAtterno());
					flag = Boolean.TRUE;
				}
				if (!o.getAtter().equals(item.getAtter())){
					o.setAtter(item.getAtter());
					flag = Boolean.TRUE;
				}
				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}

	private void getItfTblWxWxxmXjdDownload(String synTaskNo, JSONArray jsonArray,
											List<ItfTblWxWxxmXjdDownload> addRec,
											List<ItfTblWxWxxmXjdDownload> upRec) {
		List<ItfTblWxWxxmXjdDownload> oldRec =  itfTblWxWxxmXjdDownloadService.lambdaQuery().list();
		Map<String, List<ItfTblWxWxxmXjdDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfTblWxWxxmXjdDownload::getId));

		Boolean flag = Boolean.FALSE;
		for (int i = 0; i < jsonArray.size(); i++) {
			flag = Boolean.FALSE;
			JSONObject aData = jsonArray.getJSONObject(i);
			ItfTblWxWxxmXjdDownload item = JSON.toJavaObject(aData,ItfTblWxWxxmXjdDownload.class);
			if (StringUtils.isEmpty(item.getWxdm())){
				continue;
			}
			if (StringUtils.isEmpty(item.getCpdl())){
				continue;
			}

			if (StringUtils.isEmpty(item.getMshu())){
				item.setMshu("");
			}

			if (StringUtils.isEmpty(item.getXmfl())){
				item.setXmfl("");
			}

			if (oldRecMap.containsKey(item.getId())){
				ItfTblWxWxxmXjdDownload o = oldRecMap.get(item.getId()).get(0);

				if (!o.getCpdl().equals(item.getCpdl())){
					o.setCpdl(item.getCpdl());
					flag = Boolean.TRUE;
				}
				if (!o.getMshu().equals(item.getMshu())){
					o.setMshu(item.getMshu());
					flag = Boolean.TRUE;
				}
				if (!o.getWxdm().equals(item.getWxdm())){
					o.setWxdm(item.getWxdm());
					flag = Boolean.TRUE;
				}
				if (!o.getXmfl().equals(item.getXmfl())){
					o.setXmfl(item.getXmfl());
					flag = Boolean.TRUE;
				}

				if (flag){
					o.setSynTime(new Date());
					upRec.add(o);
				}
			} else {
				item.setSynTaskNo(synTaskNo);
				item.setSynReqTime(new Date());
				item.setSynStatus(1);
				item.setSynTime(new Date());
				item.setSynTimes(0);
				addRec.add(item);
			}
		}
	}
}
